@@ -252,7 +252,6 @@ static int setup_qmi_qmux(struct modem_info *modem,
 
 	ofono_modem_set_driver(modem->modem, "gobi");
 	ofono_modem_set_string(modem->modem, "Device", qmi->devnode);
-	ofono_modem_set_string(modem->modem, "DeviceProtocol", "qmux");
 	ofono_modem_set_string(modem->modem, "InterfaceNumber", net->number);
 
 	ofono_modem_set_string(modem->modem, "Bus", "usb");
@@ -278,8 +277,7 @@ static int setup_qmi_qrtr(struct modem_info *modem,
 		return -ENOTSUP;
 	}
 
-	ofono_modem_set_driver(modem->modem, "gobi");
-	ofono_modem_set_string(modem->modem, "DeviceProtocol", "qrtr");
+	ofono_modem_set_driver(modem->modem, "qrtrqmi");
 
 	return setup_qmi_netdev(modem, net);
 }
@@ -309,7 +307,7 @@ static gboolean setup_gobi_qrtr_premux(struct modem_info *modem,
 	return TRUE;
 }
 
-static gboolean setup_gobi_qrtr(struct modem_info *modem)
+static gboolean setup_qrtrsoc(struct modem_info *modem)
 {
 	const struct device_info *ipa_info = NULL;
 	int premux_count = 0;
@@ -357,9 +355,6 @@ static gboolean setup_gobi(struct modem_info *modem)
 {
 	const struct device_info *qmi = NULL;
 	const struct device_info *net = NULL;
-	const char *mdm = NULL;
-	const char *gps = NULL;
-	const char *diag = NULL;
 	GSList *list;
 
 	DBG("%s", modem->syspath);
@@ -377,38 +372,16 @@ static gboolean setup_gobi(struct modem_info *modem)
 			qmi = info;
 		else if (g_strcmp0(subsystem, "net") == 0) /* wwan */
 			net = info;
-		else if (g_strcmp0(subsystem, "tty") == 0) {
-			if (g_strcmp0(info->interface, "255/255/255") == 0) {
-				if (g_strcmp0(info->number, "00") == 0)
-					diag = info->devnode; /* ec20 */
-				else if (g_strcmp0(info->number, "01") == 0)
-					diag = info->devnode; /* gobi */
-				else if (g_strcmp0(info->number, "02") == 0)
-					mdm = info->devnode; /* gobi */
-				else if (g_strcmp0(info->number, "03") == 0)
-					gps = info->devnode; /* gobi */
-			} else if (g_strcmp0(info->interface, "255/0/0") == 0) {
-				if (g_strcmp0(info->number, "01") == 0)
-					gps = info->devnode; /* ec20 */
-				if (g_strcmp0(info->number, "02") == 0)
-					mdm = info->devnode; /* ec20 */
-				/* ignore the 3rd device second AT/mdm iface */
-			}
-		}
 	}
 
-	if (qmi == NULL || mdm == NULL || net == NULL)
+	if (qmi == NULL || net == NULL)
 		return FALSE;
 
-	DBG("qmi=%s net=%s mdm=%s gps=%s diag=%s",
-			qmi->devnode, get_ifname(net), mdm, gps, diag);
+	DBG("qmi=%s net=%s", qmi->devnode, get_ifname(net));
 
 	if (setup_qmi_qmux(modem, qmi, net) < 0)
 		return FALSE;
 
-	ofono_modem_set_string(modem->modem, "Modem", mdm);
-	ofono_modem_set_string(modem->modem, "Diag", diag);
-
 	return TRUE;
 }
 
@@ -1072,7 +1045,8 @@ static gboolean setup_quectel_usb(struct modem_info *modem)
 			mdm = info->devnode;
 			if (aux != NULL)
 				break;
-		} else if (g_strcmp0(info->interface, "255/255/255") == 0) {
+		} else if (g_strcmp0(info->interface, "255/255/255") == 0 ||
+				g_strcmp0(info->interface, "255/0/0") == 0) {
 			if (g_strcmp0(info->number, "02") == 0)
 				aux = info->devnode;
 			else if (g_strcmp0(info->number, "03") == 0)
@@ -1798,7 +1772,7 @@ static struct {
 	{ "wavecom",	setup_wavecom		},
 	{ "tc65",	setup_tc65		},
 	{ "ehs6",	setup_ehs6		},
-	{ "gobiqrtr",	setup_gobi_qrtr		},
+	{ "qrtrsoc",	setup_qrtrsoc		},
 	{ "mhi",	setup_mhi		},
 	{ }
 };
@@ -2172,14 +2146,17 @@ static struct {
 	{ "samsung",	"option",	"04e8", "6889"	},
 	{ "samsung",	"kalmia"			},
 	{ "quectel",	"option",	"05c6", "9090"	},
+	{ "quectel",	"option",	"2c7c", "6007"	},
 	{ "quectelqmi",	"qmi_wwan",	"2c7c", "0121"	},
 	{ "quectelqmi",	"qcserial",	"2c7c", "0121"	},
 	{ "quectelqmi",	"qmi_wwan",	"2c7c", "0125"	},
 	{ "quectelqmi",	"qcserial",	"2c7c", "0125"	},
 	{ "quectelqmi",	"qmi_wwan",	"2c7c", "0195"	},
 	{ "quectelqmi",	"qcserial",	"2c7c", "0195"	},
+	{ "quectelqmi",	"option",	"2c7c", "0195"	},
 	{ "quectelqmi",	"qmi_wwan",	"2c7c", "0296"	},
 	{ "quectelqmi",	"qcserial",	"2c7c", "0296"	},
+	{ "quectelqmi",	"option",	"2c7c", "0296"	},
 	{ "quectelqmi", "qmi_wwan",	"2c7c", "0800"	},
 	{ "quectelqmi", "qcserial",	"2c7c", "0800"	},
 	{ "quectelqmi", "option",	"2c7c", "0800"	},
@@ -2487,7 +2464,7 @@ static void check_net_device(struct udev_device *device)
 
 	/* Collect all rmnet devices with this iflink under a common path. */
 	sprintf(path, "/embedded/qrtr/%s", iflink);
-	add_device(path, NULL, "gobiqrtr", NULL, NULL, MODEM_TYPE_EMBEDDED,
+	add_device(path, NULL, "qrtrsoc", NULL, NULL, MODEM_TYPE_EMBEDDED,
 							device, "qrtr");
 }
 
